summary refs log tree commit diff
path: root/gnu
diff options
context:
space:
mode:
Diffstat (limited to 'gnu')
-rw-r--r--gnu/tests/base.scm12
1 files changed, 4 insertions, 8 deletions
diff --git a/gnu/tests/base.scm b/gnu/tests/base.scm
index bf2d095709..0f19449508 100644
--- a/gnu/tests/base.scm
+++ b/gnu/tests/base.scm
@@ -128,17 +128,13 @@ info --version")
             "root\n"
             (begin
               (marionette-control "sendkey ctrl-alt-f1" marionette)
               ;; Wait for the 'term-tty1' service to be running
               (marionette-eval
                '(begin
                   (use-modules (gnu services herd))
-
-                  (let loop ((i 0))
-                    (when (> i 10)
-                      (error "terminal service not running" (current-services)))
-                    (unless (memq 'term-tty1 (current-services))
-                      (sleep 1)
-                      (loop (+ i 1)))))
+                  (start-service 'term-tty1))
                marionette)
 
               ;; Now we can type.
@@ -128,17 +128,13 @@ info --version")
             (begin
               (marionette-control "sendkey ctrl-alt-f1" marionette)
-              ;; Wait for the 'term-tty1' service to be running
+              ;; Wait for the 'term-tty1' service to be running (using
+              ;; 'start-service' is the simplest and most reliable way to do
+              ;; that.)
               (marionette-eval
                '(begin